/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <qapp_macro.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>

// module include
#include "pyside2_qtremoteobjects_python.h"

// main header
#include "qremoteobjectnode_wrapper.h"

// inner classes

// Extra includes
#include <QList>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qthread.h>
#include <QtCore/qurl.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <qobjectdefs.h>


#include <cctype>
#include <cstring>

QT_WARNING_DISABLE_DEPRECATED



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

QRemoteObjectNodeWrapper::QRemoteObjectNodeWrapper(QObject * parent) : QRemoteObjectNode(parent)
{
    // ... middle
}

QRemoteObjectNodeWrapper::QRemoteObjectNodeWrapper(const QUrl & registryAddress, QObject * parent) : QRemoteObjectNode(registryAddress, parent)
{
    // ... middle
}

void QRemoteObjectNodeWrapper::childEvent(QChildEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::childEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QCHILDEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QRemoteObjectNodeWrapper::connectNotify(const QMetaMethod & signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::connectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QRemoteObjectNodeWrapper::customEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::customEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QRemoteObjectNodeWrapper::disconnectNotify(const QMetaMethod & signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::disconnectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QRemoteObjectNodeWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QRemoteObjectNode.event", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QRemoteObjectNodeWrapper::eventFilter(QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), watched),
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QRemoteObjectNode.eventFilter", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QRemoteObjectNodeWrapper::setName(const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "setName"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QRemoteObjectNode::setName(name);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QRemoteObjectNodeWrapper::setRegistryUrl(const QUrl & registryAddress)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "setRegistryUrl"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QRemoteObjectNode::setRegistryUrl(registryAddress);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &registryAddress)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QRemoteObjectNode.setRegistryUrl", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRemoteObjectNodeWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QRemoteObjectNode::timerEvent(arg__1);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject *QRemoteObjectNodeWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRemoteObjectNode::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRemoteObjectNodeWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRemoteObjectNode::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRemoteObjectNodeWrapper::qt_metacast(const char *_clname)
{
        if (!_clname) return {};
        SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void *>(const_cast< QRemoteObjectNodeWrapper *>(this));
        return QRemoteObjectNode::qt_metacast(_clname);
}

QRemoteObjectNodeWrapper::~QRemoteObjectNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRemoteObjectNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    const char *argNames[] = {"parent"};
    const QMetaObject *metaObject;
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRemoteObjectNode >()))
        return -1;

    ::QRemoteObjectNodeWrapper *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QRemoteObjectNode", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QRemoteObjectNode::QRemoteObjectNode(QObject*)
    // 1: QRemoteObjectNode::QRemoteObjectNode(QUrl,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QRemoteObjectNode(QObject*)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QRemoteObjectNode(QUrl,QObject*)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QRemoteObjectNode(QUrl,QObject*)
        }
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRemoteObjectNode(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNode_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QRemoteObjectNode(QObject * parent)
        {
            if (kwds) {
                PyObject *keyName = nullptr;
                PyObject *value = nullptr;
                keyName = Py_BuildValue("s","parent");
                if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItemString(kwds, "parent");
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtRemoteObjects.QRemoteObjectNode(): got multiple values for keyword argument 'parent'.");
                    return -1;
                                } else if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0]))))
                        goto Sbk_QRemoteObjectNode_Init_TypeError;
                }
}
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // QRemoteObjectNode(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                if (addr) {
                    cptr = new (addr) ::QRemoteObjectNodeWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(0);
                } else {
                    cptr = new ::QRemoteObjectNodeWrapper(cppArg0);
                }

                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QRemoteObjectNode(const QUrl & registryAddress, QObject * parent)
        {
            if (kwds) {
                PyObject *keyName = nullptr;
                PyObject *value = nullptr;
                keyName = Py_BuildValue("s","parent");
                if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItemString(kwds, "parent");
                if (value && pyArgs[1]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtRemoteObjects.QRemoteObjectNode(): got multiple values for keyword argument 'parent'.");
                    return -1;
                                } else if (value) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[1]))))
                        goto Sbk_QRemoteObjectNode_Init_TypeError;
                }
}
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[0]))
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!PyErr_Occurred()) {
                // QRemoteObjectNode(QUrl,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                if (addr) {
                    cptr = new (addr) ::QRemoteObjectNodeWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(0);
                } else {
                    cptr = new ::QRemoteObjectNodeWrapper(*cppArg0, cppArg1);
                }

                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRemoteObjectNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QRemoteObjectNode_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QRemoteObjectNode_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtRemoteObjects.QRemoteObjectNode");
        return -1;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_acquireDynamic(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::acquireDynamic(QString)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // acquireDynamic(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_acquireDynamic_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // acquireDynamic(QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRemoteObjectDynamicReplica * cppResult = cppSelf->acquireDynamic(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTDYNAMICREPLICA_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QRemoteObjectNodeFunc_acquireDynamic_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.acquireDynamic");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_acquireModel(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::acquireModel(QString)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // acquireModel(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_acquireModel_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // acquireModel(QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAbstractItemModelReplica * cppResult = cppSelf->acquireModel(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtRemoteObjectsTypes[SBK_QABSTRACTITEMMODELREPLICA_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QRemoteObjectNodeFunc_acquireModel_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.acquireModel");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_addClientSideConnection(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::addClientSideConnection(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QIODEVICE_IDX]), (pyArg)))) {
        overloadId = 0; // addClientSideConnection(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_addClientSideConnection_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // addClientSideConnection(QIODevice*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->addClientSideConnection(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QRemoteObjectNodeFunc_addClientSideConnection_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.addClientSideConnection");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_connectToNode(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::connectToNode(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArg)))) {
        overloadId = 0; // connectToNode(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_connectToNode_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // connectToNode(QUrl)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->connectToNode(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QRemoteObjectNodeFunc_connectToNode_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.connectToNode");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_heartbeatInterval(PyObject *self)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // heartbeatInterval()const
            int cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->heartbeatInterval();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_instances(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::instances(QString)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // instances(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_instances_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // instances(QString)const
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->instances(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QRemoteObjectNodeFunc_instances_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.instances");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_lastError(PyObject *self)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // lastError()const
            QRemoteObjectNode::ErrorCode cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->lastError();
            pyResult = Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX])->converter, &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_persistedStore(PyObject *self)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // persistedStore()const
            QRemoteObjectAbstractPersistedStore * cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->persistedStore();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTABSTRACTPERSISTEDSTORE_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_registry(PyObject *self)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // registry()const
            const QRemoteObjectRegistry * cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->registry();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTREGISTRY_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_registryUrl(PyObject *self)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // registryUrl()const
            QUrl cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->registryUrl();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setHeartbeatInterval(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setHeartbeatInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHeartbeatInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_setHeartbeatInterval_TypeError;

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setHeartbeatInterval(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHeartbeatInterval(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QRemoteObjectNodeFunc_setHeartbeatInterval_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.setHeartbeatInterval");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setName(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_setName_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setName(QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QRemoteObjectNode::setName(cppArg0) : cppSelf->setName(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QRemoteObjectNodeFunc_setName_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.setName");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setPersistedStore(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setPersistedStore(QRemoteObjectAbstractPersistedStore*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTABSTRACTPERSISTEDSTORE_IDX]), (pyArg)))) {
        overloadId = 0; // setPersistedStore(QRemoteObjectAbstractPersistedStore*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_setPersistedStore_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRemoteObjectAbstractPersistedStore *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setPersistedStore(QRemoteObjectAbstractPersistedStore*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPersistedStore(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QRemoteObjectNodeFunc_setPersistedStore_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.setPersistedStore");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setRegistryUrl(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setRegistryUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArg)))) {
        overloadId = 0; // setRegistryUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_setRegistryUrl_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setRegistryUrl(QUrl)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QRemoteObjectNode::setRegistryUrl(*cppArg0) : cppSelf->setRegistryUrl(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QRemoteObjectNodeFunc_setRegistryUrl_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.setRegistryUrl");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_timerEvent_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // timerEvent(QTimerEvent*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QRemoteObjectNode::timerEvent(cppArg0) : cppSelf->timerEvent(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QRemoteObjectNodeFunc_timerEvent_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtRemoteObjects.QRemoteObjectNode.timerEvent");
        return {};
}

static PyObject *Sbk_QRemoteObjectNodeFunc_waitForRegistry(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QRemoteObjectNode *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtRemoteObjects.QRemoteObjectNode.waitForRegistry(): too many arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|O:waitForRegistry", &(pyArgs[0])))
        return {};


    // Overloaded function decisor
    // 0: QRemoteObjectNode::waitForRegistry(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForRegistry(int)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForRegistry(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRemoteObjectNodeFunc_waitForRegistry_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","timeout");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "timeout");
            if (value && pyArgs[0]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtRemoteObjects.QRemoteObjectNode.waitForRegistry(): got multiple values for keyword argument 'timeout'.");
                return {};
                        } else if (value) {
                pyArgs[0] = value;
                if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                    goto Sbk_QRemoteObjectNodeFunc_waitForRegistry_TypeError;
            }
}
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // waitForRegistry(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->waitForRegistry(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QRemoteObjectNodeFunc_waitForRegistry_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtRemoteObjects.QRemoteObjectNode.waitForRegistry");
        return {};
}

static PyMethodDef Sbk_QRemoteObjectNode_methods[] = {
    {"acquireDynamic", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_acquireDynamic), METH_O},
    {"acquireModel", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_acquireModel), METH_O},
    {"addClientSideConnection", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_addClientSideConnection), METH_O},
    {"connectToNode", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_connectToNode), METH_O},
    {"heartbeatInterval", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_heartbeatInterval), METH_NOARGS},
    {"instances", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_instances), METH_O},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_lastError), METH_NOARGS},
    {"persistedStore", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_persistedStore), METH_NOARGS},
    {"registry", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_registry), METH_NOARGS},
    {"registryUrl", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_registryUrl), METH_NOARGS},
    {"setHeartbeatInterval", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setHeartbeatInterval), METH_O},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setName), METH_O},
    {"setPersistedStore", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setPersistedStore), METH_O},
    {"setRegistryUrl", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setRegistryUrl), METH_O},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_timerEvent), METH_O},
    {"waitForRegistry", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_waitForRegistry), METH_VARARGS|METH_KEYWORDS},

    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRemoteObjectNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QRemoteObjectNode_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QRemoteObjectNode_Type = nullptr;
static SbkObjectType *Sbk_QRemoteObjectNode_TypeF(void)
{
    return _Sbk_QRemoteObjectNode_Type;
}

static PyType_Slot Sbk_QRemoteObjectNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRemoteObjectNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRemoteObjectNode_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRemoteObjectNode_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRemoteObjectNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRemoteObjectNode_spec = {
    "PySide2.QtRemoteObjects.QRemoteObjectNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QRemoteObjectNode_slots
};

} //extern "C"

static void *Sbk_QRemoteObjectNode_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QRemoteObjectNode *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QRemoteObjectNode_ErrorCode_PythonToCpp_QRemoteObjectNode_ErrorCode(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QRemoteObjectNode::ErrorCode *>(cppOut) =
        static_cast<::QRemoteObjectNode::ErrorCode>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QRemoteObjectNode_ErrorCode_PythonToCpp_QRemoteObjectNode_ErrorCode_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX]))
        return QRemoteObjectNode_ErrorCode_PythonToCpp_QRemoteObjectNode_ErrorCode;
    return {};
}
static PyObject *QRemoteObjectNode_ErrorCode_CppToPython_QRemoteObjectNode_ErrorCode(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QRemoteObjectNode::ErrorCode *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX], castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRemoteObjectNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QRemoteObjectNode_TypeF())))
        return QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRemoteObjectNode_PTR_CppToPython_QRemoteObjectNode(const void *cppIn) {
    return PySide::getWrapperForQObject(reinterpret_cast<::QRemoteObjectNode *>(const_cast<void *>(cppIn)), Sbk_QRemoteObjectNode_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRemoteObjectNode_SignatureStrings[] = {
    "1:PySide2.QtRemoteObjects.QRemoteObjectNode(parent:PySide2.QtCore.QObject=nullptr)",
    "0:PySide2.QtRemoteObjects.QRemoteObjectNode(registryAddress:PySide2.QtCore.QUrl,parent:PySide2.QtCore.QObject=nullptr)",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.acquireDynamic(name:QString)->PySide2.QtRemoteObjects.QRemoteObjectDynamicReplica",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.acquireModel(name:QString)->PySide2.QtRemoteObjects.QAbstractItemModelReplica",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.addClientSideConnection(ioDevice:PySide2.QtCore.QIODevice)",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.connectToNode(address:PySide2.QtCore.QUrl)->bool",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.heartbeatInterval()->int",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.instances(typeName:QString)->QStringList",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.lastError()->PySide2.QtRemoteObjects.QRemoteObjectNode.ErrorCode",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.persistedStore()->PySide2.QtRemoteObjects.QRemoteObjectAbstractPersistedStore",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.registry()->PySide2.QtRemoteObjects.QRemoteObjectRegistry",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.registryUrl()->PySide2.QtCore.QUrl",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.setHeartbeatInterval(interval:int)",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.setName(name:QString)",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.setPersistedStore(persistedStore:PySide2.QtRemoteObjects.QRemoteObjectAbstractPersistedStore)",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.setRegistryUrl(registryAddress:PySide2.QtCore.QUrl)->bool",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.timerEvent(arg__1:PySide2.QtCore.QTimerEvent)",
    "PySide2.QtRemoteObjects.QRemoteObjectNode.waitForRegistry(timeout:int=30000)->bool",
    nullptr}; // Sentinel

void init_QRemoteObjectNode(PyObject *module)
{
    _Sbk_QRemoteObjectNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRemoteObjectNode",
        "QRemoteObjectNode*",
        &Sbk_QRemoteObjectNode_spec,
        QRemoteObjectNode_SignatureStrings,
        &Shiboken::callCppDestructor< ::QRemoteObjectNode >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]),
        0,
        0    );
    
    SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QRemoteObjectNode_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QRemoteObjectNode_TypeF(),
        QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR,
        is_QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR_Convertible,
        QRemoteObjectNode_PTR_CppToPython_QRemoteObjectNode);

    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode*");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectNodeWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_QRemoteObjectNode_TypeF(), &Sbk_QRemoteObjectNode_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'ErrorCode'.
    SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QRemoteObjectNode_TypeF(),
        "ErrorCode",
        "PySide2.QtRemoteObjects.QRemoteObjectNode.ErrorCode",
        "QRemoteObjectNode::ErrorCode");
    if (!SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "NoError", (long) QRemoteObjectNode::ErrorCode::NoError))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "RegistryNotAcquired", (long) QRemoteObjectNode::ErrorCode::RegistryNotAcquired))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "RegistryAlreadyHosted", (long) QRemoteObjectNode::ErrorCode::RegistryAlreadyHosted))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "NodeIsNoServer", (long) QRemoteObjectNode::ErrorCode::NodeIsNoServer))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "ServerAlreadyCreated", (long) QRemoteObjectNode::ErrorCode::ServerAlreadyCreated))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "UnintendedRegistryHosting", (long) QRemoteObjectNode::ErrorCode::UnintendedRegistryHosting))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "OperationNotValidOnClientNode", (long) QRemoteObjectNode::ErrorCode::OperationNotValidOnClientNode))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "SourceNotRegistered", (long) QRemoteObjectNode::ErrorCode::SourceNotRegistered))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "MissingObjectName", (long) QRemoteObjectNode::ErrorCode::MissingObjectName))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "HostUrlInvalid", (long) QRemoteObjectNode::ErrorCode::HostUrlInvalid))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "ProtocolMismatch", (long) QRemoteObjectNode::ErrorCode::ProtocolMismatch))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
        Sbk_QRemoteObjectNode_TypeF(), "ListenFailed", (long) QRemoteObjectNode::ErrorCode::ListenFailed))
        return;
    // Register converter for enum 'QRemoteObjectNode::ErrorCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX],
            QRemoteObjectNode_ErrorCode_CppToPython_QRemoteObjectNode_ErrorCode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRemoteObjectNode_ErrorCode_PythonToCpp_QRemoteObjectNode_ErrorCode,
            is_QRemoteObjectNode_ErrorCode_PythonToCpp_QRemoteObjectNode_ErrorCode_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtRemoteObjectsTypes[SBK_QREMOTEOBJECTNODE_ERRORCODE_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode::ErrorCode");
        Shiboken::Conversions::registerConverterName(converter, "ErrorCode");
    }
    // End of 'ErrorCode' enum.

    PySide::Signal::registerSignals(Sbk_QRemoteObjectNode_TypeF(), &::QRemoteObjectNode::staticMetaObject);

    qRegisterMetaType< ::QRemoteObjectNode::ErrorCode >("QRemoteObjectNode::ErrorCode");
    Shiboken::ObjectType::setSubTypeInitHook(Sbk_QRemoteObjectNode_TypeF(), &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(Sbk_QRemoteObjectNode_TypeF(), &::QRemoteObjectNode::staticMetaObject, sizeof(::QRemoteObjectNode));
}
