/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <qapp_macro.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>

// module include
#include "pyside2_qtwebenginewidgets_python.h"

// main header
#include "qwebenginepage_wrapper.h"

// inner classes

// Extra includes
#include <QList>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qurl.h>
#include <QtGui/qcolor.h>
#include <QtGui/qicon.h>
#include <QtGui/qpagelayout.h>
#include <QtNetwork/qauthenticator.h>
#include <QtWebChannel/qwebchannel.h>
#include <QtWebEngineCore/qwebenginehttprequest.h>
#include <QtWebEngineWidgets/qwebenginecertificateerror.h>
#include <QtWebEngineWidgets/qwebenginecontextmenudata.h>
#include <QtWebEngineWidgets/qwebenginefullscreenrequest.h>
#include <QtWebEngineWidgets/qwebenginehistory.h>
#include <QtWebEngineWidgets/qwebenginepage.h>
#include <QtWebEngineWidgets/qwebengineprofile.h>
#include <QtWebEngineWidgets/qwebenginescriptcollection.h>
#include <QtWebEngineWidgets/qwebenginesettings.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qmenu.h>
#include <QtWidgets/qwidget.h>
#include <qobjectdefs.h>


#include <cctype>
#include <cstring>

QT_WARNING_DISABLE_DEPRECATED



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

QWebEnginePageWrapper::QWebEnginePageWrapper(QObject * parent) : QWebEnginePage(parent)
{
    // ... middle
}

QWebEnginePageWrapper::QWebEnginePageWrapper(QWebEngineProfile * profile, QObject * parent) : QWebEnginePage(profile, parent)
{
    // ... middle
}

bool QWebEnginePageWrapper::acceptNavigationRequest(const QUrl & url, QWebEnginePage::NavigationType type, bool isMainFrame)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "acceptNavigationRequest"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &url),
        Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX])->converter, &type),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &isMainFrame)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.acceptNavigationRequest", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebEnginePageWrapper::certificateError(const QWebEngineCertificateError & certificateError)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "certificateError"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWebEnginePage::certificateError(certificateError);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINECERTIFICATEERROR_IDX]), &certificateError)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.certificateError", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::childEvent(QChildEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::childEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QCHILDEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

QStringList QWebEnginePageWrapper::chooseFiles(QWebEnginePage::FileSelectionMode mode, const QStringList & oldFiles, const QStringList & acceptedMimeTypes)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QStringList();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "chooseFiles"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWebEnginePage::chooseFiles(mode, oldFiles, acceptedMimeTypes);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX])->converter, &mode),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], &oldFiles),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], &acceptedMimeTypes)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QStringList();
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.chooseFiles", "QStringList", Py_TYPE(pyResult)->tp_name);
        return ::QStringList();
    }
    ::QStringList cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::connectNotify(const QMetaMethod & signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::connectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

QWebEnginePage * QWebEnginePageWrapper::createWindow(QWebEnginePage::WebWindowType type)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return nullptr;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createWindow"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWebEnginePage::createWindow(type);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX])->converter, &type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return nullptr;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.createWindow", reinterpret_cast<PyTypeObject *>(Shiboken::SbkType< QWebEnginePage >())->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWebEnginePage *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::customEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::customEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QWebEnginePageWrapper::disconnectNotify(const QMetaMethod & signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::disconnectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QWebEnginePageWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWebEnginePage::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.event", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QWebEnginePageWrapper::eventFilter(QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), watched),
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.eventFilter", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QWebEnginePageWrapper::javaScriptAlert(const QUrl & securityOrigin, const QString & msg)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "javaScriptAlert"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QWebEnginePage::javaScriptAlert(securityOrigin, msg);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &msg)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QWebEnginePageWrapper::javaScriptConfirm(const QUrl & securityOrigin, const QString & msg)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "javaScriptConfirm"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWebEnginePage::javaScriptConfirm(securityOrigin, msg);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &msg)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.javaScriptConfirm", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel level, const QString & message, int lineNumber, const QString & sourceID)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "javaScriptConsoleMessage"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QWebEnginePage::javaScriptConsoleMessage(level, message, lineNumber, sourceID);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNiN)",
        Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX])->converter, &level),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &message),
        lineNumber,
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &sourceID)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QWebEnginePageWrapper::javaScriptPrompt(const QUrl & securityOrigin, const QString & msg, const QString & defaultValue, QString * result)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "javaScriptPrompt"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QWebEnginePage::javaScriptPrompt(securityOrigin, msg, defaultValue, result);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &msg),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &defaultValue),
        Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &result)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QWebEnginePage.javaScriptPrompt", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::timerEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QWebEnginePageWrapper::triggerAction(QWebEnginePage::WebAction action, bool checked)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "triggerAction"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QWebEnginePage::triggerAction(action, checked);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX])->converter, &action),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &checked)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

const QMetaObject *QWebEnginePageWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEnginePage::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEnginePageWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEnginePage::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEnginePageWrapper::qt_metacast(const char *_clname)
{
        if (!_clname) return {};
        SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void *>(const_cast< QWebEnginePageWrapper *>(this));
        return QWebEnginePage::qt_metacast(_clname);
}

QWebEnginePageWrapper::~QWebEnginePageWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEnginePage_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    const char *argNames[] = {"parent"};
    const QMetaObject *metaObject;
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEnginePage >()))
        return -1;

    ::QWebEnginePageWrapper *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QWebEnginePage", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QWebEnginePage::QWebEnginePage(QObject*)
    // 1: QWebEnginePage::QWebEnginePage(QWebEngineProfile*,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QWebEnginePage(QObject*)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPROFILE_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QWebEnginePage(QWebEngineProfile*,QObject*)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QWebEnginePage(QWebEngineProfile*,QObject*)
        }
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QWebEnginePage(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePage_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEnginePage(QObject * parent)
        {
            if (kwds) {
                PyObject *keyName = nullptr;
                PyObject *value = nullptr;
                keyName = Py_BuildValue("s","parent");
                if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItemString(kwds, "parent");
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage(): got multiple values for keyword argument 'parent'.");
                    return -1;
                                } else if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0]))))
                        goto Sbk_QWebEnginePage_Init_TypeError;
                }
}
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = Q_NULLPTR;
            if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // QWebEnginePage(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                if (addr) {
                    cptr = new (addr) ::QWebEnginePageWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(0);
                } else {
                    cptr = new ::QWebEnginePageWrapper(cppArg0);
                }

                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QWebEnginePage(QWebEngineProfile * profile, QObject * parent)
        {
            if (kwds) {
                PyObject *keyName = nullptr;
                PyObject *value = nullptr;
                keyName = Py_BuildValue("s","parent");
                if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItemString(kwds, "parent");
                if (value && pyArgs[1]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage(): got multiple values for keyword argument 'parent'.");
                    return -1;
                                } else if (value) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[1]))))
                        goto Sbk_QWebEnginePage_Init_TypeError;
                }
}
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEngineProfile *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = Q_NULLPTR;
            if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!PyErr_Occurred()) {
                // QWebEnginePage(QWebEngineProfile*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                if (addr) {
                    cptr = new (addr) ::QWebEnginePageWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(0);
                } else {
                    cptr = new ::QWebEnginePageWrapper(cppArg0, cppArg1);
                }

                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEnginePage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebEnginePage_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QWebEnginePage_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage");
        return -1;
}

static PyObject *Sbk_QWebEnginePageFunc_acceptNavigationRequest(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "acceptNavigationRequest", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::acceptNavigationRequest(QUrl,QWebEnginePage::NavigationType,bool)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX])->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
        overloadId = 0; // acceptNavigationRequest(QUrl,QWebEnginePage::NavigationType,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_acceptNavigationRequest_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[0]))
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QWebEnginePage::NavigationType cppArg1{QWebEnginePage::NavigationTypeLinkClicked};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        bool cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!PyErr_Occurred()) {
            // acceptNavigationRequest(QUrl,QWebEnginePage::NavigationType,bool)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::acceptNavigationRequest(*cppArg0, cppArg1, cppArg2) : cppSelf->acceptNavigationRequest(*cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_acceptNavigationRequest_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.acceptNavigationRequest");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_action(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::action(QWebEnginePage::WebAction)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX])->converter, (pyArg)))) {
        overloadId = 0; // action(QWebEnginePage::WebAction)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_action_TypeError;

    // Call function/method
    {
        ::QWebEnginePage::WebAction cppArg0{QWebEnginePage::Back};
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // action(QWebEnginePage::WebAction)const
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAction * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->action(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWidgetsTypes[SBK_QACTION_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_action_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.action");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_backgroundColor(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // backgroundColor()const
            QColor cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->backgroundColor();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QCOLOR_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_certificateError(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::certificateError(QWebEngineCertificateError)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINECERTIFICATEERROR_IDX]), (pyArg)))) {
        overloadId = 0; // certificateError(QWebEngineCertificateError)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_certificateError_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineCertificateError *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // certificateError(QWebEngineCertificateError)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::certificateError(*cppArg0) : cppSelf->certificateError(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_certificateError_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.certificateError");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_chooseFiles(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "chooseFiles", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::chooseFiles(QWebEnginePage::FileSelectionMode,QStringList,QStringList)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX])->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], (pyArgs[2])))) {
        overloadId = 0; // chooseFiles(QWebEnginePage::FileSelectionMode,QStringList,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_chooseFiles_TypeError;

    // Call function/method
    {
        ::QWebEnginePage::FileSelectionMode cppArg0{QWebEnginePage::FileSelectOpen};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStringList cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QStringList cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!PyErr_Occurred()) {
            // chooseFiles(QWebEnginePage::FileSelectionMode,QStringList,QStringList)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::chooseFiles(cppArg0, cppArg1, cppArg2) : cppSelf->chooseFiles(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_chooseFiles_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.chooseFiles");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_contentsSize(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // contentsSize()const
            QSizeF cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->contentsSize();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QSIZEF_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_contextMenuData(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // contextMenuData()const
            const QWebEngineContextMenuData & cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->contextMenuData();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINECONTEXTMENUDATA_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_createStandardContextMenu(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // createStandardContextMenu()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QMenu * cppResult = cppSelf->createStandardContextMenu();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWidgetsTypes[SBK_QMENU_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_createWindow(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::createWindow(QWebEnginePage::WebWindowType)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX])->converter, (pyArg)))) {
        overloadId = 0; // createWindow(QWebEnginePage::WebWindowType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_createWindow_TypeError;

    // Call function/method
    {
        ::QWebEnginePage::WebWindowType cppArg0{QWebEnginePage::WebBrowserWindow};
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // createWindow(QWebEnginePage::WebWindowType)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QWebEnginePage * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::createWindow(cppArg0) : cppSelf->createWindow(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_createWindow_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.createWindow");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_devToolsPage(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // devToolsPage()const
            QWebEnginePage * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->devToolsPage();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_download(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.download(): too many arguments");
        return {};
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.download(): not enough arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|OO:download", &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::download(QUrl,QString)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // download(QUrl,QString)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
            overloadId = 0; // download(QUrl,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_download_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","filename");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "filename");
            if (value && pyArgs[1]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.download(): got multiple values for keyword argument 'filename'.");
                return {};
                        } else if (value) {
                pyArgs[1] = value;
                if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1]))))
                    goto Sbk_QWebEnginePageFunc_download_TypeError;
            }
}
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[0]))
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1 = QString();
        if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // download(QUrl,QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->download(*cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_download_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.download");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_event(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_event_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // event(QEvent*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::event(cppArg0) : cppSelf->event(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_event_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.event");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_findText(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.findText(): too many arguments");
        return {};
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.findText(): not enough arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|OO:findText", &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::findText(QString,QFlags<QWebEnginePage::FindFlag>)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // findText(QString,QFlags<QWebEnginePage::FindFlag>)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, (pyArgs[1])))) {
            overloadId = 0; // findText(QString,QFlags<QWebEnginePage::FindFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_findText_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","options");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "options");
            if (value && pyArgs[1]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.findText(): got multiple values for keyword argument 'options'.");
                return {};
                        } else if (value) {
                pyArgs[1] = value;
                if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, (pyArgs[1]))))
                    goto Sbk_QWebEnginePageFunc_findText_TypeError;
            }
}
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QWebEnginePage::FindFlag> cppArg1 = QWebEnginePage::FindFlags();
        if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // findText(QString,QFlags<QWebEnginePage::FindFlag>)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->findText(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_findText_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.findText");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_hasSelection(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // hasSelection()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->hasSelection();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_history(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // history()const
            QWebEngineHistory * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->history();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORY_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_icon(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // icon()const
            QIcon cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->icon();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QICON_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_iconUrl(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // iconUrl()const
            QUrl cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->iconUrl();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_inspectedPage(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // inspectedPage()const
            QWebEnginePage * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->inspectedPage();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_isAudioMuted(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isAudioMuted()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->isAudioMuted();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptAlert(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptAlert", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptAlert(QUrl,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        overloadId = 0; // javaScriptAlert(QUrl,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_javaScriptAlert_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[0]))
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // javaScriptAlert(QUrl,QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::javaScriptAlert(*cppArg0, cppArg1) : cppSelf->javaScriptAlert(*cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_javaScriptAlert_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptAlert");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptConfirm(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptConfirm", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptConfirm(QUrl,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        overloadId = 0; // javaScriptConfirm(QUrl,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_javaScriptConfirm_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[0]))
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // javaScriptConfirm(QUrl,QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::javaScriptConfirm(*cppArg0, cppArg1) : cppSelf->javaScriptConfirm(*cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_javaScriptConfirm_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptConfirm");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptConsoleMessage(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr, nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptConsoleMessage", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel,QString,int,QString)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX])->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[3])))) {
        overloadId = 0; // javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel,QString,int,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_javaScriptConsoleMessage_TypeError;

    // Call function/method
    {
        ::QWebEnginePage::JavaScriptConsoleMessageLevel cppArg0{QWebEnginePage::InfoMessageLevel};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (!PyErr_Occurred()) {
            // javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel,QString,int,QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::javaScriptConsoleMessage(cppArg0, cppArg1, cppArg2, cppArg3) : cppSelf->javaScriptConsoleMessage(cppArg0, cppArg1, cppArg2, cppArg3);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_javaScriptConsoleMessage_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptConsoleMessage");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptPrompt(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr, nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptPrompt", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptPrompt(QUrl,QString,QString,QString*)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[3])))) {
        overloadId = 0; // javaScriptPrompt(QUrl,QString,QString,QString*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_javaScriptPrompt_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[0]))
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString *cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (!PyErr_Occurred()) {
            // javaScriptPrompt(QUrl,QString,QString,QString*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::javaScriptPrompt(*cppArg0, cppArg1, cppArg2, cppArg3) : cppSelf->javaScriptPrompt(*cppArg0, cppArg1, cppArg2, cppArg3);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QWebEnginePageFunc_javaScriptPrompt_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptPrompt");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_load(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::load(QUrl)
    // 1: QWebEnginePage::load(QWebEngineHttpRequest)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEHTTPREQUEST_IDX]), (pyArg)))) {
        overloadId = 1; // load(QWebEngineHttpRequest)
    } else if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArg)))) {
        overloadId = 0; // load(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_load_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // load(const QUrl & url)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp))
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (!PyErr_Occurred()) {
                // load(QUrl)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->load(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // load(const QWebEngineHttpRequest & request)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QWebEngineHttpRequest *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (!PyErr_Occurred()) {
                // load(QWebEngineHttpRequest)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->load(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_load_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.load");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_printToPdf(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.printToPdf(): too many arguments");
        return {};
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.printToPdf(): not enough arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|OO:printToPdf", &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::printToPdf(QString,QPageLayout)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // printToPdf(QString,QPageLayout)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QPAGELAYOUT_IDX]), (pyArgs[1])))) {
            overloadId = 0; // printToPdf(QString,QPageLayout)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_printToPdf_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","layout");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "layout");
            if (value && pyArgs[1]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.printToPdf(): got multiple values for keyword argument 'layout'.");
                return {};
                        } else if (value) {
                pyArgs[1] = value;
                if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QPAGELAYOUT_IDX]), (pyArgs[1]))))
                    goto Sbk_QWebEnginePageFunc_printToPdf_TypeError;
            }
}
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPageLayout cppArg1_local = QPageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF());
        ::QPageLayout *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QPAGELAYOUT_IDX]), pythonToCpp[1]))
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);
        }

        if (!PyErr_Occurred()) {
            // printToPdf(QString,QPageLayout)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->printToPdf(cppArg0, *cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_printToPdf_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.printToPdf");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_profile(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // profile()const
            QWebEngineProfile * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->profile();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPROFILE_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_recentlyAudible(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // recentlyAudible()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->recentlyAudible();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_replaceMisspelledWord(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::replaceMisspelledWord(QString)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // replaceMisspelledWord(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_replaceMisspelledWord_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // replaceMisspelledWord(QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->replaceMisspelledWord(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_replaceMisspelledWord_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.replaceMisspelledWord");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_requestedUrl(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // requestedUrl()const
            QUrl cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->requestedUrl();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_runJavaScript(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "runJavaScript", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::runJavaScript(QString)
    // 1: QWebEnginePage::runJavaScript(QString,quint32)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // runJavaScript(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            overloadId = 1; // runJavaScript(QString,quint32)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_runJavaScript_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // runJavaScript(const QString & scriptSource)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // runJavaScript(QString)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->runJavaScript(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // runJavaScript(const QString & scriptSource, quint32 worldId)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            quint32 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!PyErr_Occurred()) {
                // runJavaScript(QString,quint32)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->runJavaScript(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_runJavaScript_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.runJavaScript");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_save(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.save(): too many arguments");
        return {};
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.save(): not enough arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|OO:save", &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::save(QString,QWebEngineDownloadItem::SavePageFormat)const
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // save(QString,QWebEngineDownloadItem::SavePageFormat)const
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEDOWNLOADITEM_SAVEPAGEFORMAT_IDX])->converter, (pyArgs[1])))) {
            overloadId = 0; // save(QString,QWebEngineDownloadItem::SavePageFormat)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_save_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","format");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "format");
            if (value && pyArgs[1]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.save(): got multiple values for keyword argument 'format'.");
                return {};
                        } else if (value) {
                pyArgs[1] = value;
                if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEDOWNLOADITEM_SAVEPAGEFORMAT_IDX])->converter, (pyArgs[1]))))
                    goto Sbk_QWebEnginePageFunc_save_TypeError;
            }
}
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QWebEngineDownloadItem::SavePageFormat cppArg1 = QWebEngineDownloadItem::MimeHtmlSaveFormat;
        if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // save(QString,QWebEngineDownloadItem::SavePageFormat)const
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const_cast<const ::QWebEnginePage *>(cppSelf)->save(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_save_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.save");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_scripts(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // scripts()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QWebEngineScriptCollection & cppResult = cppSelf->scripts();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::referenceToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINESCRIPTCOLLECTION_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_scrollPosition(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // scrollPosition()const
            QPointF cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->scrollPosition();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QPOINTF_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_selectedText(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // selectedText()const
            QString cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->selectedText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_setAudioMuted(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setAudioMuted(bool)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAudioMuted(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setAudioMuted_TypeError;

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setAudioMuted(bool)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAudioMuted(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setAudioMuted_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.setAudioMuted");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setBackgroundColor(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QCOLOR_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setBackgroundColor_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QCOLOR_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setBackgroundColor(QColor)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBackgroundColor(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setBackgroundColor_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.setBackgroundColor");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setContent(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.setContent(): too many arguments");
        return {};
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.setContent(): not enough arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|OOO:setContent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setContent(QByteArray,QString,QUrl)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QBYTEARRAY_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setContent(QByteArray,QString,QUrl)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setContent(QByteArray,QString,QUrl)
            } else if ((pythonToCpp[2] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[2])))) {
                overloadId = 0; // setContent(QByteArray,QString,QUrl)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setContent_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","mimeType");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "mimeType");
            if (value && pyArgs[1]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.setContent(): got multiple values for keyword argument 'mimeType'.");
                return {};
                        } else if (value) {
                pyArgs[1] = value;
                if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1]))))
                    goto Sbk_QWebEnginePageFunc_setContent_TypeError;
            }
            }
            keyName = Py_BuildValue("s","baseUrl");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "baseUrl");
            if (value && pyArgs[2]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.setContent(): got multiple values for keyword argument 'baseUrl'.");
                return {};
                        } else if (value) {
                pyArgs[2] = value;
                if (!(pythonToCpp[2] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[2]))))
                    goto Sbk_QWebEnginePageFunc_setContent_TypeError;
            }
}
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QBYTEARRAY_IDX]), pythonToCpp[0]))
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1 = QString();
        if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QUrl cppArg2_local = QUrl();
        ::QUrl *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[2]))
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);
        }

        if (!PyErr_Occurred()) {
            // setContent(QByteArray,QString,QUrl)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setContent(*cppArg0, cppArg1, *cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setContent_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.setContent");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setDevToolsPage(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setDevToolsPage(QWebEnginePage*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]), (pyArg)))) {
        overloadId = 0; // setDevToolsPage(QWebEnginePage*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setDevToolsPage_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEnginePage *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setDevToolsPage(QWebEnginePage*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setDevToolsPage(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setDevToolsPage_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.setDevToolsPage");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setFeaturePermission(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFeaturePermission", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setFeaturePermission(QUrl,QWebEnginePage::Feature,QWebEnginePage::PermissionPolicy)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX])->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX])->converter, (pyArgs[2])))) {
        overloadId = 0; // setFeaturePermission(QUrl,QWebEnginePage::Feature,QWebEnginePage::PermissionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setFeaturePermission_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[0]))
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QWebEnginePage::Feature cppArg1{QWebEnginePage::Notifications};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QWebEnginePage::PermissionPolicy cppArg2{QWebEnginePage::PermissionUnknown};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!PyErr_Occurred()) {
            // setFeaturePermission(QUrl,QWebEnginePage::Feature,QWebEnginePage::PermissionPolicy)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setFeaturePermission(*cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setFeaturePermission_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.setFeaturePermission");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setHtml(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.setHtml(): too many arguments");
        return {};
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.setHtml(): not enough arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|OO:setHtml", &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setHtml(QString,QUrl)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setHtml(QString,QUrl)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setHtml(QString,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setHtml_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","baseUrl");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "baseUrl");
            if (value && pyArgs[1]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.setHtml(): got multiple values for keyword argument 'baseUrl'.");
                return {};
                        } else if (value) {
                pyArgs[1] = value;
                if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArgs[1]))))
                    goto Sbk_QWebEnginePageFunc_setHtml_TypeError;
            }
}
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local = QUrl();
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp[1]))
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);
        }

        if (!PyErr_Occurred()) {
            // setHtml(QString,QUrl)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHtml(cppArg0, *cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setHtml_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.setHtml");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setInspectedPage(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setInspectedPage(QWebEnginePage*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]), (pyArg)))) {
        overloadId = 0; // setInspectedPage(QWebEnginePage*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setInspectedPage_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEnginePage *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setInspectedPage(QWebEnginePage*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setInspectedPage(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setInspectedPage_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.setInspectedPage");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setUrl_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setUrl(QUrl)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setUrl(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setUrl_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.setUrl");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setView(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setView(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWidgetsTypes[SBK_QWIDGET_IDX]), (pyArg)))) {
        overloadId = 0; // setView(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setView_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setView(QWidget*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setView(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setView_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.setView");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setWebChannel(PyObject *self, PyObject *args)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setWebChannel", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setWebChannel(QWebChannel*)
    // 1: QWebEnginePage::setWebChannel(QWebChannel*,uint)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNEL_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setWebChannel(QWebChannel*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[1])))) {
            overloadId = 1; // setWebChannel(QWebChannel*,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setWebChannel_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setWebChannel(QWebChannel * arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWebChannel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // setWebChannel(QWebChannel*)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWebChannel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setWebChannel(QWebChannel * arg__1, uint worldId)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWebChannel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            uint cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!PyErr_Occurred()) {
                // setWebChannel(QWebChannel*,uint)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWebChannel(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setWebChannel_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.setWebChannel");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_setZoomFactor(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setZoomFactor(qreal)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setZoomFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_setZoomFactor_TypeError;

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setZoomFactor(qreal)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setZoomFactor(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_setZoomFactor_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtWebEngineWidgets.QWebEnginePage.setZoomFactor");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_settings(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // settings()const
            QWebEngineSettings * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->settings();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINESETTINGS_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_title(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // title()const
            QString cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->title();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_triggerAction(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.triggerAction(): too many arguments");
        return {};
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.triggerAction(): not enough arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|OO:triggerAction", &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::triggerAction(QWebEnginePage::WebAction,bool)
    if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX])->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // triggerAction(QWebEnginePage::WebAction,bool)
        } else if ((pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // triggerAction(QWebEnginePage::WebAction,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebEnginePageFunc_triggerAction_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","checked");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "checked");
            if (value && pyArgs[1]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtWebEngineWidgets.QWebEnginePage.triggerAction(): got multiple values for keyword argument 'checked'.");
                return {};
                        } else if (value) {
                pyArgs[1] = value;
                if (!(pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                    goto Sbk_QWebEnginePageFunc_triggerAction_TypeError;
            }
}
        }
        ::QWebEnginePage::WebAction cppArg0{QWebEnginePage::Back};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = false;
        if (pythonToCpp[1]) pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // triggerAction(QWebEnginePage::WebAction,bool)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::triggerAction(cppArg0, cppArg1) : cppSelf->triggerAction(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QWebEnginePageFunc_triggerAction_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtWebEngineWidgets.QWebEnginePage.triggerAction");
        return {};
}

static PyObject *Sbk_QWebEnginePageFunc_url(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QURL_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_view(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // view()const
            QWidget * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->view();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWidgetsTypes[SBK_QWIDGET_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_webChannel(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // webChannel()const
            QWebChannel * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->webChannel();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNEL_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_zoomFactor(PyObject *self)
{
    ::QWebEnginePage *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // zoomFactor()const
            qreal cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->zoomFactor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QWebEnginePage_methods[] = {
    {"acceptNavigationRequest", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_acceptNavigationRequest), METH_VARARGS},
    {"action", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_action), METH_O},
    {"backgroundColor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_backgroundColor), METH_NOARGS},
    {"certificateError", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_certificateError), METH_O},
    {"chooseFiles", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_chooseFiles), METH_VARARGS},
    {"contentsSize", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_contentsSize), METH_NOARGS},
    {"contextMenuData", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_contextMenuData), METH_NOARGS},
    {"createStandardContextMenu", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_createStandardContextMenu), METH_NOARGS},
    {"createWindow", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_createWindow), METH_O},
    {"devToolsPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_devToolsPage), METH_NOARGS},
    {"download", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_download), METH_VARARGS|METH_KEYWORDS},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_event), METH_O},
    {"findText", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_findText), METH_VARARGS|METH_KEYWORDS},
    {"hasSelection", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_hasSelection), METH_NOARGS},
    {"history", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_history), METH_NOARGS},
    {"icon", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_icon), METH_NOARGS},
    {"iconUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_iconUrl), METH_NOARGS},
    {"inspectedPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_inspectedPage), METH_NOARGS},
    {"isAudioMuted", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_isAudioMuted), METH_NOARGS},
    {"javaScriptAlert", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptAlert), METH_VARARGS},
    {"javaScriptConfirm", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptConfirm), METH_VARARGS},
    {"javaScriptConsoleMessage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptConsoleMessage), METH_VARARGS},
    {"javaScriptPrompt", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptPrompt), METH_VARARGS},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_load), METH_O},
    {"printToPdf", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_printToPdf), METH_VARARGS|METH_KEYWORDS},
    {"profile", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_profile), METH_NOARGS},
    {"recentlyAudible", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_recentlyAudible), METH_NOARGS},
    {"replaceMisspelledWord", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_replaceMisspelledWord), METH_O},
    {"requestedUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_requestedUrl), METH_NOARGS},
    {"runJavaScript", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_runJavaScript), METH_VARARGS},
    {"save", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_save), METH_VARARGS|METH_KEYWORDS},
    {"scripts", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_scripts), METH_NOARGS},
    {"scrollPosition", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_scrollPosition), METH_NOARGS},
    {"selectedText", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_selectedText), METH_NOARGS},
    {"setAudioMuted", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setAudioMuted), METH_O},
    {"setBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setBackgroundColor), METH_O},
    {"setContent", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setContent), METH_VARARGS|METH_KEYWORDS},
    {"setDevToolsPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setDevToolsPage), METH_O},
    {"setFeaturePermission", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setFeaturePermission), METH_VARARGS},
    {"setHtml", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setHtml), METH_VARARGS|METH_KEYWORDS},
    {"setInspectedPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setInspectedPage), METH_O},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setUrl), METH_O},
    {"setView", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setView), METH_O},
    {"setWebChannel", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setWebChannel), METH_VARARGS},
    {"setZoomFactor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setZoomFactor), METH_O},
    {"settings", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_settings), METH_NOARGS},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_title), METH_NOARGS},
    {"triggerAction", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_triggerAction), METH_VARARGS|METH_KEYWORDS},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_url), METH_NOARGS},
    {"view", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_view), METH_NOARGS},
    {"webChannel", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_webChannel), METH_NOARGS},
    {"zoomFactor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_zoomFactor), METH_NOARGS},

    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEnginePage_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QWebEnginePage_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QWebEnginePage_Type = nullptr;
static SbkObjectType *Sbk_QWebEnginePage_TypeF(void)
{
    return _Sbk_QWebEnginePage_Type;
}

static PyType_Slot Sbk_QWebEnginePage_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEnginePage_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEnginePage_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEnginePage_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEnginePage_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEnginePage_spec = {
    "PySide2.QtWebEngineWidgets.QWebEnginePage",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEnginePage_slots
};

} //extern "C"

static void *Sbk_QWebEnginePage_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QWebEnginePage *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}

PyObject * SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___and__(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage::FindFlags cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QWebEnginePage::FindFlags>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QWebEnginePage::FindFlags>(int(PyLong_AsLong(pyArg)));
#else
    cppSelf = static_cast<::QWebEnginePage::FindFlags>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QWebEnginePage::FindFlags>(int(PyInt_AsLong(pyArg)));
#endif

    cppResult = cppSelf & cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, &cppResult);
}

PyObject * SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___or__(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage::FindFlags cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QWebEnginePage::FindFlags>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QWebEnginePage::FindFlags>(int(PyLong_AsLong(pyArg)));
#else
    cppSelf = static_cast<::QWebEnginePage::FindFlags>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QWebEnginePage::FindFlags>(int(PyInt_AsLong(pyArg)));
#endif

    cppResult = cppSelf | cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, &cppResult);
}

PyObject * SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___xor__(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage::FindFlags cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QWebEnginePage::FindFlags>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QWebEnginePage::FindFlags>(int(PyLong_AsLong(pyArg)));
#else
    cppSelf = static_cast<::QWebEnginePage::FindFlags>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QWebEnginePage::FindFlags>(int(PyInt_AsLong(pyArg)));
#endif

    cppResult = cppSelf ^ cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___invert__(PyObject *self, PyObject *pyArg)
{
    ::QWebEnginePage::FindFlags cppSelf;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, self, &cppSelf);
    ::QWebEnginePage::FindFlags cppResult = ~cppSelf;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, &cppResult);
}

static PyObject *SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag_long(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, self, &val);
    return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &val);
}
static int SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag__nonzero(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX])->converter, self, &val);
    return val != 0;
}

static PyType_Slot SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag_number_slots[] = {
#ifdef IS_PY3K
    {Py_nb_bool,    (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag__nonzero},
#else
    {Py_nb_nonzero, (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag__nonzero},
    {Py_nb_long,    (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag_long},
#endif
    {Py_nb_invert,  (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___invert__},
    {Py_nb_and,     (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___and__},
    {Py_nb_xor,     (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___xor__},
    {Py_nb_or,      (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag___or__},
    {Py_nb_int,     (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag_long},
#ifndef IS_PY3K
    {Py_nb_long,    (void *)SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag_long},
#endif
    {0, nullptr} // sentinel
};



// Type conversion functions.

// Python to C++ enum conversion.
static void QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::WebAction *>(cppOut) =
        static_cast<::QWebEnginePage::WebAction>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX]))
        return QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction;
    return {};
}
static PyObject *QWebEnginePage_WebAction_CppToPython_QWebEnginePage_WebAction(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::WebAction *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX], castCppIn);

}

static void QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::FindFlag *>(cppOut) =
        static_cast<::QWebEnginePage::FindFlag>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX]))
        return QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag;
    return {};
}
static PyObject *QWebEnginePage_FindFlag_CppToPython_QWebEnginePage_FindFlag(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::FindFlag *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX], castCppIn);

}

static void QFlags_QWebEnginePage_FindFlag__PythonToCpp_QFlags_QWebEnginePage_FindFlag_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QWebEnginePage::FindFlag> *>(cppOut) =
        ::QFlags<QWebEnginePage::FindFlag>(QFlag(int(PySide::QFlags::getValue(reinterpret_cast<PySideQFlagsObject *>(pyIn)))));

}
static PythonToCppFunc is_QFlags_QWebEnginePage_FindFlag__PythonToCpp_QFlags_QWebEnginePage_FindFlag__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX]))
        return QFlags_QWebEnginePage_FindFlag__PythonToCpp_QFlags_QWebEnginePage_FindFlag_;
    return {};
}
static PyObject *QFlags_QWebEnginePage_FindFlag__CppToPython_QFlags_QWebEnginePage_FindFlag_(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QFlags<QWebEnginePage::FindFlag> *>(cppIn));
    return reinterpret_cast<PyObject *>(PySide::QFlags::newObject(castCppIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX]));

}

static void QWebEnginePage_FindFlag_PythonToCpp_QFlags_QWebEnginePage_FindFlag_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QWebEnginePage::FindFlag> *>(cppOut) =
        ::QFlags<QWebEnginePage::FindFlag>(QFlag(int(Shiboken::Enum::getValue(pyIn))));

}
static PythonToCppFunc is_QWebEnginePage_FindFlag_PythonToCpp_QFlags_QWebEnginePage_FindFlag__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX]))
        return QWebEnginePage_FindFlag_PythonToCpp_QFlags_QWebEnginePage_FindFlag_;
    return {};
}
static void number_PythonToCpp_QFlags_QWebEnginePage_FindFlag_(PyObject *pyIn, void *cppOut) {
    Shiboken::AutoDecRef pyLong(PyNumber_Long(pyIn));
    *reinterpret_cast<::QFlags<QWebEnginePage::FindFlag> *>(cppOut) =
        ::QFlags<QWebEnginePage::FindFlag>(QFlag(int(PyLong_AsLong(pyLong.object()))));

}
static PythonToCppFunc is_number_PythonToCpp_QFlags_QWebEnginePage_FindFlag__Convertible(PyObject *pyIn) {
    if (PyNumber_Check(pyIn) && PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX]))
        return number_PythonToCpp_QFlags_QWebEnginePage_FindFlag_;
    return {};
}
static void QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::WebWindowType *>(cppOut) =
        static_cast<::QWebEnginePage::WebWindowType>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX]))
        return QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType;
    return {};
}
static PyObject *QWebEnginePage_WebWindowType_CppToPython_QWebEnginePage_WebWindowType(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::WebWindowType *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX], castCppIn);

}

static void QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::PermissionPolicy *>(cppOut) =
        static_cast<::QWebEnginePage::PermissionPolicy>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX]))
        return QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy;
    return {};
}
static PyObject *QWebEnginePage_PermissionPolicy_CppToPython_QWebEnginePage_PermissionPolicy(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::PermissionPolicy *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX], castCppIn);

}

static void QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::NavigationType *>(cppOut) =
        static_cast<::QWebEnginePage::NavigationType>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX]))
        return QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType;
    return {};
}
static PyObject *QWebEnginePage_NavigationType_CppToPython_QWebEnginePage_NavigationType(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::NavigationType *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX], castCppIn);

}

static void QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::Feature *>(cppOut) =
        static_cast<::QWebEnginePage::Feature>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX]))
        return QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature;
    return {};
}
static PyObject *QWebEnginePage_Feature_CppToPython_QWebEnginePage_Feature(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::Feature *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX], castCppIn);

}

static void QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::FileSelectionMode *>(cppOut) =
        static_cast<::QWebEnginePage::FileSelectionMode>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX]))
        return QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode;
    return {};
}
static PyObject *QWebEnginePage_FileSelectionMode_CppToPython_QWebEnginePage_FileSelectionMode(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::FileSelectionMode *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX], castCppIn);

}

static void QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::JavaScriptConsoleMessageLevel *>(cppOut) =
        static_cast<::QWebEnginePage::JavaScriptConsoleMessageLevel>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX]))
        return QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel;
    return {};
}
static PyObject *QWebEnginePage_JavaScriptConsoleMessageLevel_CppToPython_QWebEnginePage_JavaScriptConsoleMessageLevel(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::JavaScriptConsoleMessageLevel *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX], castCppIn);

}

static void QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QWebEnginePage::RenderProcessTerminationStatus *>(cppOut) =
        static_cast<::QWebEnginePage::RenderProcessTerminationStatus>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX]))
        return QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus;
    return {};
}
static PyObject *QWebEnginePage_RenderProcessTerminationStatus_CppToPython_QWebEnginePage_RenderProcessTerminationStatus(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::RenderProcessTerminationStatus *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX], castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEnginePage_PythonToCpp_QWebEnginePage_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEnginePage_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEnginePage_PythonToCpp_QWebEnginePage_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QWebEnginePage_TypeF())))
        return QWebEnginePage_PythonToCpp_QWebEnginePage_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEnginePage_PTR_CppToPython_QWebEnginePage(const void *cppIn) {
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEnginePage *>(const_cast<void *>(cppIn)), Sbk_QWebEnginePage_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QWebEnginePage_SignatureStrings[] = {
    "1:PySide2.QtWebEngineWidgets.QWebEnginePage(parent:PySide2.QtCore.QObject=Q_NULLPTR)",
    "0:PySide2.QtWebEngineWidgets.QWebEnginePage(profile:PySide2.QtWebEngineWidgets.QWebEngineProfile,parent:PySide2.QtCore.QObject=Q_NULLPTR)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.acceptNavigationRequest(url:PySide2.QtCore.QUrl,type:PySide2.QtWebEngineWidgets.QWebEnginePage.NavigationType,isMainFrame:bool)->bool",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.action(action:PySide2.QtWebEngineWidgets.QWebEnginePage.WebAction)->PySide2.QtWidgets.QAction",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.backgroundColor()->PySide2.QtGui.QColor",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.certificateError(certificateError:PySide2.QtWebEngineWidgets.QWebEngineCertificateError)->bool",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.chooseFiles(mode:PySide2.QtWebEngineWidgets.QWebEnginePage.FileSelectionMode,oldFiles:QStringList,acceptedMimeTypes:QStringList)->QStringList",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.contentsSize()->PySide2.QtCore.QSizeF",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.contextMenuData()->PySide2.QtWebEngineWidgets.QWebEngineContextMenuData",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.createStandardContextMenu()->PySide2.QtWidgets.QMenu",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.createWindow(type:PySide2.QtWebEngineWidgets.QWebEnginePage.WebWindowType)->PySide2.QtWebEngineWidgets.QWebEnginePage",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.devToolsPage()->PySide2.QtWebEngineWidgets.QWebEnginePage",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.download(url:PySide2.QtCore.QUrl,filename:QString=QString())",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.event(arg__1:PySide2.QtCore.QEvent)->bool",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.findText(subString:QString,options:PySide2.QtWebEngineWidgets.QWebEnginePage.FindFlags=QWebEnginePage.FindFlags())",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.hasSelection()->bool",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.history()->PySide2.QtWebEngineWidgets.QWebEngineHistory",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.icon()->PySide2.QtGui.QIcon",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.iconUrl()->PySide2.QtCore.QUrl",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.inspectedPage()->PySide2.QtWebEngineWidgets.QWebEnginePage",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.isAudioMuted()->bool",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptAlert(securityOrigin:PySide2.QtCore.QUrl,msg:QString)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptConfirm(securityOrigin:PySide2.QtCore.QUrl,msg:QString)->bool",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptConsoleMessage(level:PySide2.QtWebEngineWidgets.QWebEnginePage.JavaScriptConsoleMessageLevel,message:QString,lineNumber:int,sourceID:QString)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.javaScriptPrompt(securityOrigin:PySide2.QtCore.QUrl,msg:QString,defaultValue:QString,result:PySide2.QtCore.QString)->bool",
    "1:PySide2.QtWebEngineWidgets.QWebEnginePage.load(url:PySide2.QtCore.QUrl)",
    "0:PySide2.QtWebEngineWidgets.QWebEnginePage.load(request:PySide2.QtWebEngineCore.QWebEngineHttpRequest)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.printToPdf(filePath:QString,layout:PySide2.QtGui.QPageLayout=QPageLayout(QPageSize(QPageSize.A4), QPageLayout.Portrait, QMarginsF()))",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.profile()->PySide2.QtWebEngineWidgets.QWebEngineProfile",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.recentlyAudible()->bool",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.replaceMisspelledWord(replacement:QString)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.requestedUrl()->PySide2.QtCore.QUrl",
    "1:PySide2.QtWebEngineWidgets.QWebEnginePage.runJavaScript(scriptSource:QString)",
    "0:PySide2.QtWebEngineWidgets.QWebEnginePage.runJavaScript(scriptSource:QString,worldId:unsigned int)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.save(filePath:QString,format:PySide2.QtWebEngineWidgets.QWebEngineDownloadItem.SavePageFormat=QWebEngineDownloadItem.MimeHtmlSaveFormat)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.scripts()->PySide2.QtWebEngineWidgets.QWebEngineScriptCollection",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.scrollPosition()->PySide2.QtCore.QPointF",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.selectedText()->QString",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setAudioMuted(muted:bool)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setBackgroundColor(color:PySide2.QtGui.QColor)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setContent(data:PySide2.QtCore.QByteArray,mimeType:QString=QString(),baseUrl:PySide2.QtCore.QUrl=QUrl())",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setDevToolsPage(page:PySide2.QtWebEngineWidgets.QWebEnginePage)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setFeaturePermission(securityOrigin:PySide2.QtCore.QUrl,feature:PySide2.QtWebEngineWidgets.QWebEnginePage.Feature,policy:PySide2.QtWebEngineWidgets.QWebEnginePage.PermissionPolicy)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setHtml(html:QString,baseUrl:PySide2.QtCore.QUrl=QUrl())",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setInspectedPage(page:PySide2.QtWebEngineWidgets.QWebEnginePage)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setUrl(url:PySide2.QtCore.QUrl)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setView(view:PySide2.QtWidgets.QWidget)",
    "1:PySide2.QtWebEngineWidgets.QWebEnginePage.setWebChannel(arg__1:PySide2.QtWebChannel.QWebChannel)",
    "0:PySide2.QtWebEngineWidgets.QWebEnginePage.setWebChannel(arg__1:PySide2.QtWebChannel.QWebChannel,worldId:unsigned int)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.setZoomFactor(factor:double)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.settings()->PySide2.QtWebEngineWidgets.QWebEngineSettings",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.title()->QString",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.triggerAction(action:PySide2.QtWebEngineWidgets.QWebEnginePage.WebAction,checked:bool=false)",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.url()->PySide2.QtCore.QUrl",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.view()->PySide2.QtWidgets.QWidget",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.webChannel()->PySide2.QtWebChannel.QWebChannel",
    "PySide2.QtWebEngineWidgets.QWebEnginePage.zoomFactor()->double",
    nullptr}; // Sentinel

void init_QWebEnginePage(PyObject *module)
{
    _Sbk_QWebEnginePage_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEnginePage",
        "QWebEnginePage*",
        &Sbk_QWebEnginePage_spec,
        QWebEnginePage_SignatureStrings,
        &Shiboken::callCppDestructor< ::QWebEnginePage >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]),
        0,
        0    );
    
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QWebEnginePage_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QWebEnginePage_TypeF(),
        QWebEnginePage_PythonToCpp_QWebEnginePage_PTR,
        is_QWebEnginePage_PythonToCpp_QWebEnginePage_PTR_Convertible,
        QWebEnginePage_PTR_CppToPython_QWebEnginePage);

    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage");
    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEnginePage).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEnginePageWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_QWebEnginePage_TypeF(), &Sbk_QWebEnginePage_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'WebAction'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "WebAction",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.WebAction",
        "QWebEnginePage::WebAction");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "NoWebAction", (long) QWebEnginePage::WebAction::NoWebAction))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Back", (long) QWebEnginePage::WebAction::Back))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Forward", (long) QWebEnginePage::WebAction::Forward))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Stop", (long) QWebEnginePage::WebAction::Stop))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Reload", (long) QWebEnginePage::WebAction::Reload))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Cut", (long) QWebEnginePage::WebAction::Cut))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Copy", (long) QWebEnginePage::WebAction::Copy))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Paste", (long) QWebEnginePage::WebAction::Paste))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Undo", (long) QWebEnginePage::WebAction::Undo))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Redo", (long) QWebEnginePage::WebAction::Redo))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "SelectAll", (long) QWebEnginePage::WebAction::SelectAll))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ReloadAndBypassCache", (long) QWebEnginePage::WebAction::ReloadAndBypassCache))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "PasteAndMatchStyle", (long) QWebEnginePage::WebAction::PasteAndMatchStyle))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "OpenLinkInThisWindow", (long) QWebEnginePage::WebAction::OpenLinkInThisWindow))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "OpenLinkInNewWindow", (long) QWebEnginePage::WebAction::OpenLinkInNewWindow))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "OpenLinkInNewTab", (long) QWebEnginePage::WebAction::OpenLinkInNewTab))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "CopyLinkToClipboard", (long) QWebEnginePage::WebAction::CopyLinkToClipboard))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "DownloadLinkToDisk", (long) QWebEnginePage::WebAction::DownloadLinkToDisk))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "CopyImageToClipboard", (long) QWebEnginePage::WebAction::CopyImageToClipboard))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "CopyImageUrlToClipboard", (long) QWebEnginePage::WebAction::CopyImageUrlToClipboard))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "DownloadImageToDisk", (long) QWebEnginePage::WebAction::DownloadImageToDisk))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "CopyMediaUrlToClipboard", (long) QWebEnginePage::WebAction::CopyMediaUrlToClipboard))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleMediaControls", (long) QWebEnginePage::WebAction::ToggleMediaControls))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleMediaLoop", (long) QWebEnginePage::WebAction::ToggleMediaLoop))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleMediaPlayPause", (long) QWebEnginePage::WebAction::ToggleMediaPlayPause))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleMediaMute", (long) QWebEnginePage::WebAction::ToggleMediaMute))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "DownloadMediaToDisk", (long) QWebEnginePage::WebAction::DownloadMediaToDisk))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "InspectElement", (long) QWebEnginePage::WebAction::InspectElement))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ExitFullScreen", (long) QWebEnginePage::WebAction::ExitFullScreen))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "RequestClose", (long) QWebEnginePage::WebAction::RequestClose))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Unselect", (long) QWebEnginePage::WebAction::Unselect))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "SavePage", (long) QWebEnginePage::WebAction::SavePage))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "OpenLinkInNewBackgroundTab", (long) QWebEnginePage::WebAction::OpenLinkInNewBackgroundTab))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ViewSource", (long) QWebEnginePage::WebAction::ViewSource))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleBold", (long) QWebEnginePage::WebAction::ToggleBold))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleItalic", (long) QWebEnginePage::WebAction::ToggleItalic))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleUnderline", (long) QWebEnginePage::WebAction::ToggleUnderline))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "ToggleStrikethrough", (long) QWebEnginePage::WebAction::ToggleStrikethrough))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "AlignLeft", (long) QWebEnginePage::WebAction::AlignLeft))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "AlignCenter", (long) QWebEnginePage::WebAction::AlignCenter))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "AlignRight", (long) QWebEnginePage::WebAction::AlignRight))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "AlignJustified", (long) QWebEnginePage::WebAction::AlignJustified))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Indent", (long) QWebEnginePage::WebAction::Indent))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "Outdent", (long) QWebEnginePage::WebAction::Outdent))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "InsertOrderedList", (long) QWebEnginePage::WebAction::InsertOrderedList))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "InsertUnorderedList", (long) QWebEnginePage::WebAction::InsertUnorderedList))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
        Sbk_QWebEnginePage_TypeF(), "WebActionCount", (long) QWebEnginePage::WebAction::WebActionCount))
        return;
    // Register converter for enum 'QWebEnginePage::WebAction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX],
            QWebEnginePage_WebAction_CppToPython_QWebEnginePage_WebAction);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction,
            is_QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::WebAction");
        Shiboken::Conversions::registerConverterName(converter, "WebAction");
    }
    // End of 'WebAction' enum.

    // Initialization of enum 'FindFlag'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX] = PySide::QFlags::create("PySide2.QtWebEngineWidgets.QWebEnginePage.FindFlags", SbkPySide2_QtWebEngineWidgets_QWebEnginePage_FindFlag_number_slots);
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "FindFlag",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.FindFlag",
        "QWebEnginePage::FindFlag",
        SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX]);
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX],
        Sbk_QWebEnginePage_TypeF(), "FindBackward", (long) QWebEnginePage::FindFlag::FindBackward))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX],
        Sbk_QWebEnginePage_TypeF(), "FindCaseSensitively", (long) QWebEnginePage::FindFlag::FindCaseSensitively))
        return;
    // Register converter for enum 'QWebEnginePage::FindFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX],
            QWebEnginePage_FindFlag_CppToPython_QWebEnginePage_FindFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag,
            is_QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::FindFlag");
        Shiboken::Conversions::registerConverterName(converter, "FindFlag");
    }
    // Register converter for flag 'QFlags<QWebEnginePage::FindFlag>'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX],
            QFlags_QWebEnginePage_FindFlag__CppToPython_QFlags_QWebEnginePage_FindFlag_);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_FindFlag_PythonToCpp_QFlags_QWebEnginePage_FindFlag_,
            is_QWebEnginePage_FindFlag_PythonToCpp_QFlags_QWebEnginePage_FindFlag__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QFlags_QWebEnginePage_FindFlag__PythonToCpp_QFlags_QWebEnginePage_FindFlag_,
            is_QFlags_QWebEnginePage_FindFlag__PythonToCpp_QFlags_QWebEnginePage_FindFlag__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            number_PythonToCpp_QFlags_QWebEnginePage_FindFlag_,
            is_number_PythonToCpp_QFlags_QWebEnginePage_FindFlag__Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::FindFlags");
        Shiboken::Conversions::registerConverterName(converter, "FindFlags");
    }
    // End of 'FindFlag' enum/flags.

    // Initialization of enum 'WebWindowType'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "WebWindowType",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.WebWindowType",
        "QWebEnginePage::WebWindowType");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "WebBrowserWindow", (long) QWebEnginePage::WebWindowType::WebBrowserWindow))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "WebBrowserTab", (long) QWebEnginePage::WebWindowType::WebBrowserTab))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "WebDialog", (long) QWebEnginePage::WebWindowType::WebDialog))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "WebBrowserBackgroundTab", (long) QWebEnginePage::WebWindowType::WebBrowserBackgroundTab))
        return;
    // Register converter for enum 'QWebEnginePage::WebWindowType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX],
            QWebEnginePage_WebWindowType_CppToPython_QWebEnginePage_WebWindowType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType,
            is_QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::WebWindowType");
        Shiboken::Conversions::registerConverterName(converter, "WebWindowType");
    }
    // End of 'WebWindowType' enum.

    // Initialization of enum 'PermissionPolicy'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "PermissionPolicy",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.PermissionPolicy",
        "QWebEnginePage::PermissionPolicy");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX],
        Sbk_QWebEnginePage_TypeF(), "PermissionUnknown", (long) QWebEnginePage::PermissionPolicy::PermissionUnknown))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX],
        Sbk_QWebEnginePage_TypeF(), "PermissionGrantedByUser", (long) QWebEnginePage::PermissionPolicy::PermissionGrantedByUser))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX],
        Sbk_QWebEnginePage_TypeF(), "PermissionDeniedByUser", (long) QWebEnginePage::PermissionPolicy::PermissionDeniedByUser))
        return;
    // Register converter for enum 'QWebEnginePage::PermissionPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX],
            QWebEnginePage_PermissionPolicy_CppToPython_QWebEnginePage_PermissionPolicy);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy,
            is_QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::PermissionPolicy");
        Shiboken::Conversions::registerConverterName(converter, "PermissionPolicy");
    }
    // End of 'PermissionPolicy' enum.

    // Initialization of enum 'NavigationType'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "NavigationType",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.NavigationType",
        "QWebEnginePage::NavigationType");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "NavigationTypeLinkClicked", (long) QWebEnginePage::NavigationType::NavigationTypeLinkClicked))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "NavigationTypeTyped", (long) QWebEnginePage::NavigationType::NavigationTypeTyped))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "NavigationTypeFormSubmitted", (long) QWebEnginePage::NavigationType::NavigationTypeFormSubmitted))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "NavigationTypeBackForward", (long) QWebEnginePage::NavigationType::NavigationTypeBackForward))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "NavigationTypeReload", (long) QWebEnginePage::NavigationType::NavigationTypeReload))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX],
        Sbk_QWebEnginePage_TypeF(), "NavigationTypeOther", (long) QWebEnginePage::NavigationType::NavigationTypeOther))
        return;
    // Register converter for enum 'QWebEnginePage::NavigationType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX],
            QWebEnginePage_NavigationType_CppToPython_QWebEnginePage_NavigationType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType,
            is_QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::NavigationType");
        Shiboken::Conversions::registerConverterName(converter, "NavigationType");
    }
    // End of 'NavigationType' enum.

    // Initialization of enum 'Feature'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "Feature",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.Feature",
        "QWebEnginePage::Feature");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "Notifications", (long) QWebEnginePage::Feature::Notifications))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "Geolocation", (long) QWebEnginePage::Feature::Geolocation))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "MediaAudioCapture", (long) QWebEnginePage::Feature::MediaAudioCapture))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "MediaVideoCapture", (long) QWebEnginePage::Feature::MediaVideoCapture))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "MediaAudioVideoCapture", (long) QWebEnginePage::Feature::MediaAudioVideoCapture))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "MouseLock", (long) QWebEnginePage::Feature::MouseLock))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "DesktopVideoCapture", (long) QWebEnginePage::Feature::DesktopVideoCapture))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
        Sbk_QWebEnginePage_TypeF(), "DesktopAudioVideoCapture", (long) QWebEnginePage::Feature::DesktopAudioVideoCapture))
        return;
    // Register converter for enum 'QWebEnginePage::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX],
            QWebEnginePage_Feature_CppToPython_QWebEnginePage_Feature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature,
            is_QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::Feature");
        Shiboken::Conversions::registerConverterName(converter, "Feature");
    }
    // End of 'Feature' enum.

    // Initialization of enum 'FileSelectionMode'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "FileSelectionMode",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.FileSelectionMode",
        "QWebEnginePage::FileSelectionMode");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX],
        Sbk_QWebEnginePage_TypeF(), "FileSelectOpen", (long) QWebEnginePage::FileSelectionMode::FileSelectOpen))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX],
        Sbk_QWebEnginePage_TypeF(), "FileSelectOpenMultiple", (long) QWebEnginePage::FileSelectionMode::FileSelectOpenMultiple))
        return;
    // Register converter for enum 'QWebEnginePage::FileSelectionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX],
            QWebEnginePage_FileSelectionMode_CppToPython_QWebEnginePage_FileSelectionMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode,
            is_QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::FileSelectionMode");
        Shiboken::Conversions::registerConverterName(converter, "FileSelectionMode");
    }
    // End of 'FileSelectionMode' enum.

    // Initialization of enum 'JavaScriptConsoleMessageLevel'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "JavaScriptConsoleMessageLevel",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.JavaScriptConsoleMessageLevel",
        "QWebEnginePage::JavaScriptConsoleMessageLevel");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX],
        Sbk_QWebEnginePage_TypeF(), "InfoMessageLevel", (long) QWebEnginePage::JavaScriptConsoleMessageLevel::InfoMessageLevel))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX],
        Sbk_QWebEnginePage_TypeF(), "WarningMessageLevel", (long) QWebEnginePage::JavaScriptConsoleMessageLevel::WarningMessageLevel))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX],
        Sbk_QWebEnginePage_TypeF(), "ErrorMessageLevel", (long) QWebEnginePage::JavaScriptConsoleMessageLevel::ErrorMessageLevel))
        return;
    // Register converter for enum 'QWebEnginePage::JavaScriptConsoleMessageLevel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX],
            QWebEnginePage_JavaScriptConsoleMessageLevel_CppToPython_QWebEnginePage_JavaScriptConsoleMessageLevel);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel,
            is_QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::JavaScriptConsoleMessageLevel");
        Shiboken::Conversions::registerConverterName(converter, "JavaScriptConsoleMessageLevel");
    }
    // End of 'JavaScriptConsoleMessageLevel' enum.

    // Initialization of enum 'RenderProcessTerminationStatus'.
    SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QWebEnginePage_TypeF(),
        "RenderProcessTerminationStatus",
        "PySide2.QtWebEngineWidgets.QWebEnginePage.RenderProcessTerminationStatus",
        "QWebEnginePage::RenderProcessTerminationStatus");
    if (!SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX],
        Sbk_QWebEnginePage_TypeF(), "NormalTerminationStatus", (long) QWebEnginePage::RenderProcessTerminationStatus::NormalTerminationStatus))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX],
        Sbk_QWebEnginePage_TypeF(), "AbnormalTerminationStatus", (long) QWebEnginePage::RenderProcessTerminationStatus::AbnormalTerminationStatus))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX],
        Sbk_QWebEnginePage_TypeF(), "CrashedTerminationStatus", (long) QWebEnginePage::RenderProcessTerminationStatus::CrashedTerminationStatus))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX],
        Sbk_QWebEnginePage_TypeF(), "KilledTerminationStatus", (long) QWebEnginePage::RenderProcessTerminationStatus::KilledTerminationStatus))
        return;
    // Register converter for enum 'QWebEnginePage::RenderProcessTerminationStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX],
            QWebEnginePage_RenderProcessTerminationStatus_CppToPython_QWebEnginePage_RenderProcessTerminationStatus);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus,
            is_QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::RenderProcessTerminationStatus");
        Shiboken::Conversions::registerConverterName(converter, "RenderProcessTerminationStatus");
    }
    // End of 'RenderProcessTerminationStatus' enum.

    PySide::Signal::registerSignals(Sbk_QWebEnginePage_TypeF(), &::QWebEnginePage::staticMetaObject);

    qRegisterMetaType< ::QWebEnginePage::WebAction >("QWebEnginePage::WebAction");
    qRegisterMetaType< ::QWebEnginePage::FindFlag >("QWebEnginePage::FindFlag");
    qRegisterMetaType< ::QWebEnginePage::FindFlags >("QWebEnginePage::FindFlags");
    qRegisterMetaType< ::QWebEnginePage::WebWindowType >("QWebEnginePage::WebWindowType");
    qRegisterMetaType< ::QWebEnginePage::PermissionPolicy >("QWebEnginePage::PermissionPolicy");
    qRegisterMetaType< ::QWebEnginePage::NavigationType >("QWebEnginePage::NavigationType");
    qRegisterMetaType< ::QWebEnginePage::Feature >("QWebEnginePage::Feature");
    qRegisterMetaType< ::QWebEnginePage::FileSelectionMode >("QWebEnginePage::FileSelectionMode");
    qRegisterMetaType< ::QWebEnginePage::JavaScriptConsoleMessageLevel >("QWebEnginePage::JavaScriptConsoleMessageLevel");
    qRegisterMetaType< ::QWebEnginePage::RenderProcessTerminationStatus >("QWebEnginePage::RenderProcessTerminationStatus");
    Shiboken::ObjectType::setSubTypeInitHook(Sbk_QWebEnginePage_TypeF(), &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(Sbk_QWebEnginePage_TypeF(), &::QWebEnginePage::staticMetaObject, sizeof(::QWebEnginePage));
}
